@@ -139,6 +139,10 @@ from .read_sigel_windpower_polygons import read_sigel_windpower_polygons
 from .read_sigel_thermoelectric_plants import read_sigel_thermoelectric_plants
 from .read_drainage_ducts import read_drainage_ducts
 from .read_indigenous_village import read_indigenous_village
+from .read_regional_coordination_offices import (
+    read_regional_coordination_offices,
+    read_regional_Regional_Coordination_Offices,
+)
 from .read_indigenous_lands_in_study import read_indigenous_lands_in_study
 from .read_conservation_units import read_conservation_units
 from .read_conservation_units_without_delimitation import read_conservation_units_without_delimitation
@@ -153,3 +157,4 @@ from .read_granted_port_facilities import read_granted_port_facilities
 from .read_granted_crossing_lines import read_granted_crossing_lines
 from .read_economically_navigable_inland_waterways import read_economically_navigable_inland_waterways
 from .read_traditional_communities import read_traditional_communities
+from .read_regional_coordination_offices import read_regional_coordination_offices
\ No newline at end of file
