@@ -200,3 +200,7 @@ def read_sigel_hydroelectric_developments(simplified=False, verbose=False):
         
     return gdf
 
+if __name__ == '__main__':
+    # Example usage
+    hydro_data = read_sigel_hydroelectric_developments(simplified=False, verbose=False)
+    print(hydro_data.head())
\ No newline at end of file
