@@ -217,3 +217,8 @@ if __name__ == '__main__':
         print(f"Error: {str(e)}")
         import traceback
         traceback.print_exc()
+
+if __name__ == '__main__':
+    # Example usage
+    hydro_data = read_sigel_wind_turbines(simplified=False, verbose=False)
+    print(hydro_data.head())
\ No newline at end of file
