@@ -9,7 +9,7 @@ from pathlib import Path
 from io import BytesIO
 import warnings
 import json
-from fp.fp import FreeProxy
+import time
 
 def read_sigel_windpower_transmission_lines(simplified=False, verbose=False):
     """Download Wind Power Transmission Lines data from Sigel.
@@ -36,13 +36,9 @@ def read_sigel_windpower_transmission_lines(simplified=False, verbose=False):
     # Read wind power transmission lines data
     >>> transmission_lines = read_sigel_windpower_transmission_lines()
     """
-    proxy = FreeProxy(country_id=['BR']).get()
-    proxies = {
-        'http':proxy,
-        'https':proxy
-    }
+
     # URL for the Sigel geoserver WFS service
-    url = r'https://sigel.aneel.gov.br/arcgis/rest/services/PORTAL/ExtractDataTaskAneel/GPServer/Extract%20Data%20Task/execute?f=json&env:outSR=102100&Layers_to_Clip=["Linha de Transmissão EOL"]&Area_of_Interest={"geometryType":"esriGeometryPolygon","features":[{"geometry":{"rings":[[[-10056193.304181412,-5207437.87749587],[-10056193.304181412,2052245.3209151002],[-2405152.5209504515,2052245.3209151002],[-2405152.5209504515,-5207437.87749587],[-10056193.304181412,-5207437.87749587]]],"spatialReference":{"wkid":102100}}}],"sr":{"wkid":102100}}&Feature_Format=Shapefile - SHP - .shp&Raster_Format=Tagged Image File Format - TIFF - .tif'
+    url = r'https://sigel.aneel.gov.br/arcgis/rest/services/PORTAL/ExtractDataPro/GPServer/ExtractDataPro/submitJob?f=json&env:outSR=102100&Layers_to_Clip=["Linha de Transmissão EOL"]&Area_of_Interest={"geometryType":"esriGeometryPolygon","features":[{"geometry":{"rings":[[[-8938378.510524046,-4460571.882677736],[-8938378.510524046,1165193.3991097403],[-3058230.79860357,1165193.3991097403],[-3058230.79860357,-4460571.882677736],[-8938378.510524046,-4460571.882677736]]],"spatialReference":{"wkid":102100}}}],"sr":{"wkid":102100}}&Feature_Format=Shapefile - SHP - .shp&Raster_Format=ESRI GRID - GRID&Spatial_Reference=Same As Input'
  
     try:
         # Disable SSL verification warning
@@ -51,7 +47,7 @@ def read_sigel_windpower_transmission_lines(simplified=False, verbose=False):
         if verbose:
             print("Requesting data from Sigel server...")
             
-        response = requests.get(url, timeout=60, verify=False, proxies=proxies)
+        response = requests.get(url, timeout=60, verify=False)
         if not response.ok:
             raise Exception(f"Error getting JSON response: {response.status_code}")
 
@@ -59,18 +55,82 @@ def read_sigel_windpower_transmission_lines(simplified=False, verbose=False):
         
         if verbose:
             print(f"JSON response received: {json.dumps(json_response, indent=2)[:500]}...")
-            
-        if 'results' not in json_response or len(json_response['results']) == 0:
-            raise Exception("Invalid JSON response structure")
-            
-        if 'value' not in json_response['results'][0] or 'url' not in json_response['results'][0]['value']:
-            raise Exception("URL not found in JSON response")
-            
-        file_url = json_response['results'][0]['value']['url']
-        
+
+        job_id = json_response.get('jobId')
+        if not job_id:
+            raise Exception("Job ID not found in JSON response")
+
+        if verbose:
+            print(f"Job submitted successfully with ID: {job_id}")
+
+        job_status_url = (
+            "https://sigel.aneel.gov.br/arcgis/rest/services/PORTAL/ExtractDataPro/"
+            f"GPServer/ExtractDataPro/jobs/{job_id}"
+        )
+        max_attempts = 30
+        poll_interval = 5
+        final_status_json = None
+
+        for attempt in range(1, max_attempts + 1):
+            params = {
+                'f': 'json',
+                'dojo.preventCache': str(int(time.time() * 1000))
+            }
+            status_response = requests.get(
+                job_status_url,
+                params=params,
+                timeout=60,
+                verify=False,
+            )
+            if not status_response.ok:
+                raise Exception(f"Error checking job status: {status_response.status_code}")
+
+            status_json = status_response.json()
+            job_status = status_json.get('jobStatus')
+
+            if verbose:
+                print(f"Polling attempt {attempt}: job status = {job_status}")
+
+            if job_status == 'esriJobSucceeded':
+                final_status_json = status_json
+                break
+
+            if job_status in {'esriJobFailed', 'esriJobCancelled'}:
+                error_messages = status_json.get('messages', [])
+                raise Exception(f"Job ended with status {job_status}. Messages: {error_messages}")
+
+            time.sleep(poll_interval)
+
+        if final_status_json is None:
+            raise Exception("Job did not succeed within the expected time frame")
+
+        results_url = f"{job_status_url}/results/Output_Zip_File"
+        results_params = {
+            'f': 'json',
+            'returnType': 'data',
+            'dojo.preventCache': str(int(time.time() * 1000))
+        }
+
+        if verbose:
+            print(f"Fetching job results from: {results_url}")
+
+        results_response = requests.get(
+            results_url,
+            params=results_params,
+            timeout=60,
+            verify=False,
+        )
+        if not results_response.ok:
+            raise Exception(f"Error fetching job results: {results_response.status_code}")
+
+        results_json = results_response.json()
+        file_url = results_json.get('value', {}).get('url')
+        if not file_url:
+            raise Exception("Download URL not found in job results")
+
         if verbose:
             print(f"Downloading file from: {file_url}")
-        
+
         file_response = requests.get(file_url, stream=True, timeout=60, verify=False)
         if not file_response.ok:
             raise Exception(f"Error downloading file: {file_response.status_code}")
@@ -151,14 +211,4 @@ def read_sigel_windpower_transmission_lines(simplified=False, verbose=False):
     return gdf
 
 if __name__ == '__main__':
-    try:
-        transmission_lines_data = read_sigel_windpower_transmission_lines(verbose=True)
-        print(f"Downloaded wind power transmission lines data with {len(transmission_lines_data)} records and {len(transmission_lines_data.columns)} columns")
-        print(transmission_lines_data)
-        # Test simplified version
-        simplified_data = read_sigel_windpower_transmission_lines(simplified=True)
-        print(f"Simplified data has {len(simplified_data.columns)} columns: {simplified_data.columns.tolist()}")
-    except Exception as e:
-        print(f"Error: {str(e)}")
-        import traceback
-        traceback.print_exc()
\ No newline at end of file
+    transmission_lines_data = read_sigel_windpower_transmission_lines(verbose=True)
\ No newline at end of file
